@@ -76,7 +76,20 @@ class BFADD_Test extends PredisCommandTestCase
 
     /**
      * @group connected
-     * @group relay-incompatible
+     * @return void
+     * @requiresRedisBfVersion >= 2.6.0
+     */
+    public function testAddGivenItemIntoBloomFilterResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $actualResponse = $redis->bfadd('key', 'item');
+        $this->assertTrue($actualResponse);
+        $this->assertTrue($redis->bfexists('key', 'item'));
+    }
+
+    /**
+     * @group connected
      * @requiresRedisBfVersion >= 1.0.0
      */
     public function testThrowsExceptionOnWrongType(): void
