@@ -84,6 +84,26 @@ class BFINFO_Test extends PredisCommandTestCase
 
     /**
      * @group connected
+     * @group relay-resp3
+     * @requiresRedisBfVersion 2.6.0
+     */
+    public function testInfoReturnsCorrectInformationAboutBloomFilterResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->bfadd('key', 'item');
+        $this->assertSame([
+            'Capacity' => 100,
+            'Size' => 240,
+            'Number of filters' => 1,
+            'Number of items inserted' => 1,
+            'Expansion rate' => 2,
+        ], $redis->bfinfo('key'));
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
      * @return void
      * @requiresRedisBfVersion 1.0.0
      */
