@@ -98,6 +98,43 @@ class BFLOADCHUNK_Test extends PredisCommandTestCase
 
     /**
      * @group connected
+     * @return void
+     * @requiresRedisBfVersion >= 2.6.0
+     */
+    public function testLoadChunkSuccessfullyRestoresBloomFilterResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->bfadd('key', 'item1');
+
+        $chunks = [];
+        $iter = 0;
+
+        while (true) {
+            [$iter, $data] = $redis->bfscandump('key', $iter);
+
+            if ($iter === 0) {
+                break;
+            }
+
+            $chunks[] = [$iter, $data];
+        }
+
+        $redis->flushall();
+
+        foreach ($chunks as $chunk) {
+            [$iter, $data] = $chunk;
+            $actualResponse = $redis->bfloadchunk('key', $iter, $data);
+
+            $this->assertEquals('OK', $actualResponse);
+        }
+
+        $this->assertTrue($redis->bfexists('key', 'item1'));
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
      * @requiresRedisBfVersion >= 1.0.0
      */
     public function testThrowsExceptionOnWrongType(): void
