@@ -79,6 +79,24 @@ class BFSCANDUMP_Test extends PredisCommandTestCase
 
     /**
      * @group connected
+     * @return void
+     * @requiresRedisBfVersion >= 2.6.0
+     */
+    public function testScanDumpReturnsCorrectDataChunkResp3(): void
+    {
+        $expectedIterator = 1;
+        $redis = $this->getResp3Client();
+
+        $redis->bfadd('key', 'item1');
+        [$iterator, $dataChunk] = $redis->bfscandump('key', 0);
+
+        $this->assertSame($expectedIterator, $iterator);
+        $this->assertNotEmpty($dataChunk);
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
      * @requiresRedisBfVersion >= 1.0.0
      */
     public function testThrowsExceptionOnWrongType(): void
