@@ -79,6 +79,25 @@ class CMSINITBYPROB_Test extends PredisCommandTestCase
 
     /**
      * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRedisBfVersion >= 2.6.0
+     */
+    public function testInitializeCountMinSketchWithDesiredErrorRateAndProbabilityResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $actualResponse = $redis->cmsinitbyprob('key', 0.001, 0.01);
+        $info = $redis->cmsinfo('key');
+
+        $this->assertEquals('OK', $actualResponse);
+        $this->assertSame(2000, $info['width']);
+        $this->assertSame(7, $info['depth']);
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
      * @requiresRedisBfVersion >= 2.0.0
      */
     public function testThrowsExceptionOnAlreadyExistingKey(): void
