@@ -106,6 +106,29 @@ class GEOSEARCH_Test extends PredisCommandTestCase
         );
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisVersion >= 6.2.0
+     */
+    public function testReturnsSearchedGeospatialCoordinatesResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->geoadd('key', 1.1, 2, 'member1');
+        $redis->geoadd('key', 2.1, 3, 'member2');
+        $redis->geoadd('key', 3.1, 4, 'member3');
+
+        $this->assertSame(
+            ['member1', 'member2', 'member3'],
+            $redis->geosearch(
+                'key',
+                new FromLonLat(1, 4),
+                new ByRadius(9999, 'km')
+            )
+        );
+    }
+
     /**
      * @group connected
      * @dataProvider unexpectedValuesProvider
@@ -186,7 +209,7 @@ class GEOSEARCH_Test extends PredisCommandTestCase
                 [
                     'member1' => ['lng' => 1.1, 'lat' => 2.2],
                     'member2' => ['lng' => 2.2, 'lat' => 3.3],
-                    'member3' => ['lng' => 3.3, 'lat' => 4.4]],
+                    'member3' => ['lng' => 3.3, 'lat' => 4.4], ],
             ],
             'with WITHDIST modifier' => [
                 [['member1', '111.111'], ['member2', '222.222'], ['member3', '333.333']],
