@@ -86,6 +86,22 @@ class JSONCLEAR_Test extends PredisCommandTestCase
         $this->assertSame($expectedModifiedJson, $redis->jsonget($key));
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisJsonVersion >= 2.6.1
+     */
+    public function testClearValuesOnArraysAndObjectsResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->jsonset('key', '$', '{"key1":"value1","key2":[1,2,3,4,5,6]}');
+        $actualResponse = $redis->jsonclear('key', '$.key2');
+
+        $this->assertSame(1, $actualResponse);
+        $this->assertSame('{"key1":"value1","key2":[]}', $redis->jsonget('key'));
+    }
+
     public function jsonProvider(): array
     {
         return [
