@@ -86,6 +86,22 @@ class JSONDEL_Test extends PredisCommandTestCase
         $this->assertSame($expectedModifiedJson, $redis->jsonget($key));
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisJsonVersion >= 2.6.1
+     */
+    public function testDeletesPathsAtKeyFromGivenJsonStringResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->jsonset('key', '$', '{"key1":"value1","key2":"value2"}');
+        $actualResponse = $redis->jsondel('key', '$.key2');
+
+        $this->assertSame(1, $actualResponse);
+        $this->assertSame('{"key1":"value1"}', $redis->jsonget('key'));
+    }
+
     public function jsonProvider(): array
     {
         return [
