@@ -84,6 +84,20 @@ class JSONNUMINCRBY_Test extends PredisCommandTestCase
         $this->assertSame($expectedIncrementedResponse, $redis->jsonnumincrby($key, $path, $value));
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisJsonVersion >= 2.6.1
+     */
+    public function testIncrementJsonNumericOnGivenValueResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->jsonset('key', '$', '{"key1":"value1","key2":1}');
+
+        $this->assertSame([2], $redis->jsonnumincrby('key', '$.key2', 1));
+    }
+
     public function jsonProvider(): array
     {
         return [
