@@ -82,6 +82,20 @@ class JSONTYPE_Test extends PredisCommandTestCase
         $this->assertSame($expectedType, $redis->jsontype($key, $path));
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisJsonVersion >= 2.6.1
+     */
+    public function testReturnsJsonValueTypeResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->jsonset('key', '$', '{"key1":"value1"}');
+
+        $this->assertSame([['string']], $redis->jsontype('key', '$.key1'));
+    }
+
     public function jsonProvider(): array
     {
         return [
