@@ -138,6 +138,55 @@ class FTCURSOR_Test extends PredisCommandTestCase
     /**
      * @group connected
      * @return void
+     * @requiresRediSearchVersion >= 2.8.0
+     */
+    public function testReadAggregatedResultsFromExistingCursorResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $ftCreateArguments = (new CreateArguments())->prefix(['user:']);
+        $schema = [
+            new TextField('name'),
+            new TextField('country'),
+            new NumericField('dob', '', AbstractField::SORTABLE),
+        ];
+
+        $this->assertEquals('OK', $redis->ftcreate('idx', $schema, $ftCreateArguments));
+        $this->assertSame(
+            3,
+            $redis->hset('user:0', 'name', 'Vlad', 'country', 'Ukraine', 'dob', 813801600)
+        );
+        $this->assertSame(
+            3,
+            $redis->hset('user:1', 'name', 'Vlad', 'country', 'Israel', 'dob', 782265600)
+        );
+        $this->assertSame(
+            3,
+            $redis->hset('user:2', 'name', 'Vlad', 'country', 'Ukraine', 'dob', 813801600)
+        );
+
+        $ftAggregateArguments = (new AggregateArguments())
+            ->apply('year(@dob)', 'birth')
+            ->groupBy('@country', '@birth')
+            ->reduce('COUNT', true, 'country_birth_Vlad_count')
+            ->sortBy(0, '@birth', 'DESC')
+            ->withCursor(1);
+
+        [$response, $cursor] = $redis->ftaggregate('idx', '@name: "Vlad"', $ftAggregateArguments);
+        $actualResponse = [];
+
+        while ($cursor) {
+            $actualResponse[] = $response;
+            [$response, $cursor] = $redis->ftcursor->read('idx', $cursor);
+        }
+
+        $this->assertNotEmpty($actualResponse);
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
+     * @return void
      * @requiresRediSearchVersion >= 1.1.0
      */
     public function testDelExplicitlyRemovesExistingCursor(): void
