@@ -72,4 +72,18 @@ class FTDICTADD_Test extends PredisCommandTestCase
 
         $this->assertSame(2, $actualResponse);
     }
+
+    /**
+     * @group connected
+     * @return void
+     * @requiresRediSearchVersion >= 2.8.0
+     */
+    public function testAddTermsIntoGivenDictionaryResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $actualResponse = $redis->ftdictadd('dict', 'foo', 'bar');
+
+        $this->assertSame(2, $actualResponse);
+    }
 }
