@@ -88,6 +88,30 @@ class FTINFO_Test extends PredisCommandTestCase
 
     /**
      * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRediSearchVersion >= 2.8.0
+     */
+    public function testInfoReturnsInformationAboutGivenIndexResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $arguments = new CreateArguments();
+        $arguments->prefix(['prefix:']);
+        $arguments->language();
+
+        $schema = [new TextField('text_field')];
+
+        $createResponse = $redis->ftcreate('index', $schema, $arguments);
+        $this->assertEquals('OK', $createResponse);
+
+        $actualResponse = $redis->ftinfo('index');
+        $this->assertEquals('index', $actualResponse['index_name']);
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
      * @return void
      * @requiresRediSearchVersion >= 1.0.0
      */
