@@ -89,6 +89,38 @@ class FTSPELLCHECK_Test extends PredisCommandTestCase
 
     /**
      * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRediSearchVersion >= 2.8.0
+     */
+    public function testSpellcheckReturnsPossibleSuggestionsToGivenMisspelledTermResp3(): void
+    {
+        $redis = $this->getResp3Client();
+        $expectedResponse = [
+            'results' => [
+                'held' => [['hello' => 0.0], ['help' => 0.0]],
+            ],
+        ];
+
+        $this->assertEquals('OK', $redis->ftcreate(
+            'index',
+            [new TextField('text_field')]
+        ));
+
+        $this->assertEquals(2, $redis->ftdictadd('dict', 'hello', 'help'));
+
+        $actualResponse = $redis->ftspellcheck(
+            'index',
+            'held',
+            (new SpellcheckArguments())->distance(2)->terms('dict')
+        );
+
+        $this->assertSame($expectedResponse, $actualResponse);
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
      * @return void
      * @requiresRediSearchVersion >= 1.4.0
      */
@@ -129,19 +161,19 @@ class FTSPELLCHECK_Test extends PredisCommandTestCase
         return [
             'with default arguments' => [
                 ['index', 'query'],
-                ['index', 'query'],
+                ['index', 'query', 'DIALECT', 2],
             ],
             'with DISTANCE modifier' => [
                 ['index', 'query', (new SpellcheckArguments())->distance(2)],
-                ['index', 'query', 'DISTANCE', 2],
+                ['index', 'query', 'DISTANCE', 2, 'DIALECT', 2],
             ],
             'with TERMS modifier - INCLUDE' => [
                 ['index', 'query', (new SpellcheckArguments())->terms('dict', 'INCLUDE', 'term')],
-                ['index', 'query', 'TERMS', 'INCLUDE', 'dict', 'term'],
+                ['index', 'query', 'TERMS', 'INCLUDE', 'dict', 'term', 'DIALECT', 2],
             ],
             'with TERMS modifier - EXCLUDE' => [
                 ['index', 'query', (new SpellcheckArguments())->terms('dict', 'EXCLUDE', 'term')],
-                ['index', 'query', 'TERMS', 'EXCLUDE', 'dict', 'term'],
+                ['index', 'query', 'TERMS', 'EXCLUDE', 'dict', 'term', 'DIALECT', 2],
             ],
             'with DIALECT modifier' => [
                 ['index', 'query', (new SpellcheckArguments())->dialect('dialect')],
