@@ -84,6 +84,29 @@ class FTSYNDUMP_Test extends PredisCommandTestCase
         $this->assertSame($expectedResponse, $redis->ftsyndump('index'));
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRediSearchVersion >= 2.8.0
+     */
+    public function testDumpReturnsContentOfSynonymGroupFromGivenIndexResp3(): void
+    {
+        $redis = $this->getResp3Client();
+        $expectedResponse = ['term1' => ['synonym1'], 'term2' => ['synonym1']];
+
+        $this->assertEquals(
+            'OK',
+            $redis->ftcreate('index', [new TextField('text_field')])
+        );
+
+        $this->assertEquals(
+            'OK',
+            $redis->ftsynupdate('index', 'synonym1', null, 'term1', 'term2')
+        );
+
+        $this->assertSame($expectedResponse, $redis->ftsyndump('index'));
+    }
+
     /**
      * @group connected
      * @return void
