@@ -83,6 +83,26 @@ class TOPKINFO_Test extends PredisCommandTestCase
 
     /**
      * @group connected
+     * @group relay-resp3
+     * @return void
+     * @requiresRedisBfVersion >= 2.6.0
+     */
+    public function testReturnsInfoAboutGivenTopKStructureResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->topkreserve('key', 50);
+
+        $this->assertSameWithPrecision(
+            ['k' => 50, 'width' => 8, 'depth' => 7, 'decay' => '0.90000000000000002'],
+            $redis->topkinfo('key'),
+            1
+        );
+    }
+
+    /**
+     * @group connected
+     * @group relay-resp3
      * @return void
      * @requiresRedisBfVersion >= 2.0.0
      */
