@@ -88,6 +88,23 @@ class TOPKLIST_Test extends PredisCommandTestCase
         $this->assertEquals($expectedResponse, $actualResponse);
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisBfVersion >= 2.6.0
+     */
+    public function testReturnsListOfItemsWithinTopKStructureResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->topkreserve('key', 50);
+        $redis->topkadd('key', 1, 2, 2, 3, 3, 3);
+
+        $actualResponse = $redis->topklist('key');
+
+        $this->assertEquals(['3', '2', '1'], $actualResponse);
+    }
+
     /**
      * @group connected
      * @return void
