@@ -75,6 +75,21 @@ class TOPKQUERY_Test extends PredisCommandTestCase
         $this->assertSame([1, 0], $redis->topkquery('key', 'item1', 'item2'));
     }
 
+    /**
+     * @group connected
+     * @return void
+     * @requiresRedisBfVersion >= 2.6.0
+     */
+    public function testQueryChecksIfItemExistsWithinGivenTopKStructureResp3(): void
+    {
+        $redis = $this->getResp3Client();
+
+        $redis->topkreserve('key', 50);
+        $redis->topkadd('key', 'item1');
+
+        $this->assertSame([true, false], $redis->topkquery('key', 'item1', 'item2'));
+    }
+
     /**
      * @group connected
      * @return void
