@@ -17,6 +17,8 @@ use PHPUnit\Framework\MockObject\MockObject;
 use Predis\Cluster;
 use Predis\Command;
 use Predis\Connection;
+use Predis\Connection\FactoryInterface;
+use Predis\Connection\Parameters;
 use Predis\Response;
 use PredisTestCase;
 
@@ -27,9 +29,9 @@ class RedisClusterTest extends PredisTestCase
      */
     public function testAcceptsCustomConnectionFactory(): void
     {
-        /** @var Connection\FactoryInterface */
+        /** @var FactoryInterface */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
 
         $this->assertSame($factory, $cluster->getConnectionFactory());
     }
@@ -39,7 +41,7 @@ class RedisClusterTest extends PredisTestCase
      */
     public function testUsesRedisClusterStrategyByDefault(): void
     {
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $this->assertInstanceOf('Predis\Cluster\RedisStrategy', $cluster->getClusterStrategy());
     }
@@ -52,7 +54,7 @@ class RedisClusterTest extends PredisTestCase
         /** @var Cluster\StrategyInterface */
         $strategy = $this->getMockBuilder('Predis\Cluster\StrategyInterface')->getMock();
 
-        $cluster = new RedisCluster(new Connection\Factory(), $strategy);
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters(), $strategy);
 
         $this->assertSame($strategy, $cluster->getClusterStrategy());
     }
@@ -65,7 +67,7 @@ class RedisClusterTest extends PredisTestCase
         $connection1 = $this->getMockConnection('tcp://127.0.0.1:6379');
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -84,7 +86,7 @@ class RedisClusterTest extends PredisTestCase
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
         $connection3 = $this->getMockConnection('tcp://127.0.0.1:6371');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -102,7 +104,7 @@ class RedisClusterTest extends PredisTestCase
         $connection1 = $this->getMockConnection('tcp://127.0.0.1:6379');
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -121,7 +123,7 @@ class RedisClusterTest extends PredisTestCase
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
         $connection3 = $this->getMockConnection('tcp://127.0.0.1:6381');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -137,14 +139,14 @@ class RedisClusterTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testConnectPicksRandomConnection(): void
+    public function testConnectToEachNode(): void
     {
         $connect1 = false;
         $connect2 = false;
 
         $connection1 = $this->getMockConnection('tcp://127.0.0.1:6379');
         $connection1
-            ->expects($this->any())
+            ->expects($this->once())
             ->method('connect')
             ->willReturnCallback(function () use (&$connect1) {
                 $connect1 = true;
@@ -158,7 +160,7 @@ class RedisClusterTest extends PredisTestCase
 
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
         $connection2
-            ->expects($this->any())
+            ->expects($this->once())
             ->method('connect')
             ->willReturnCallback(function () use (&$connect2) {
                 $connect2 = true;
@@ -170,7 +172,7 @@ class RedisClusterTest extends PredisTestCase
                 return $connect2;
             });
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -178,14 +180,8 @@ class RedisClusterTest extends PredisTestCase
         $cluster->connect();
 
         $this->assertTrue($cluster->isConnected());
-
-        if ($connect1) {
-            $this->assertTrue($connect1);
-            $this->assertFalse($connect2);
-        } else {
-            $this->assertFalse($connect1);
-            $this->assertTrue($connect2);
-        }
+        $this->assertTrue($connect1);
+        $this->assertTrue($connect2);
     }
 
     /**
@@ -203,7 +199,7 @@ class RedisClusterTest extends PredisTestCase
             ->expects($this->once())
             ->method('disconnect');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -228,7 +224,7 @@ class RedisClusterTest extends PredisTestCase
             ->method('isConnected')
             ->willReturn(true);
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -253,7 +249,7 @@ class RedisClusterTest extends PredisTestCase
             ->method('isConnected')
             ->willReturn(false);
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -271,7 +267,7 @@ class RedisClusterTest extends PredisTestCase
         $connection3 = $this->getMockConnection('tcp://127.0.0.1:6383?slots=10923-16383');
         $connection4 = $this->getMockConnection('tcp://127.0.0.1:6384');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
         $cluster->useClusterSlots(false);
 
         $cluster->add($connection1);
@@ -319,14 +315,12 @@ class RedisClusterTest extends PredisTestCase
             ->withConsecutive(
                 [
                     [
-                        'scheme' => 'tcp',
                         'host' => '127.0.0.1',
                         'port' => '6383',
                     ],
                 ],
                 [
                     [
-                        'scheme' => 'tcp',
                         'host' => '127.0.0.1',
                         'port' => '6384',
                     ],
@@ -341,7 +335,7 @@ class RedisClusterTest extends PredisTestCase
         /** @var RedisCluster|MockObject */
         $cluster = $this->getMockBuilder('Predis\Connection\Cluster\RedisCluster')
             ->onlyMethods(['getRandomConnection'])
-            ->setConstructorArgs([$factory])
+            ->setConstructorArgs([$factory, new Parameters()])
             ->getMock();
         $cluster
             ->expects($this->once())
@@ -370,7 +364,7 @@ class RedisClusterTest extends PredisTestCase
         $connection1 = $this->getMockConnection('tcp://127.0.0.1:6379');
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
 
@@ -392,7 +386,7 @@ class RedisClusterTest extends PredisTestCase
         $connection1 = $this->getMockConnection('tcp://127.0.0.1:6379');
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -422,7 +416,7 @@ class RedisClusterTest extends PredisTestCase
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380?slots=5461-10922');
         $connection3 = $this->getMockConnection('tcp://127.0.0.1:6381?slots=10923-16383');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -452,7 +446,7 @@ class RedisClusterTest extends PredisTestCase
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380?slots=5461-5499,5600-10922');
         $connection3 = $this->getMockConnection('tcp://127.0.0.1:6381?slots=10923-10999,11001-16383');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -486,7 +480,7 @@ class RedisClusterTest extends PredisTestCase
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
         $connection3 = $this->getMockConnection('tcp://127.0.0.1:6381');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -511,7 +505,7 @@ class RedisClusterTest extends PredisTestCase
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
         $connection3 = $this->getMockConnection('tcp://127.0.0.1:6381');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -551,7 +545,7 @@ class RedisClusterTest extends PredisTestCase
             ->expects($this->never())
             ->method('writeRequest');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
         $cluster->useClusterSlots(false);
 
         $cluster->add($connection1);
@@ -578,7 +572,7 @@ class RedisClusterTest extends PredisTestCase
             ->method('readResponse')
             ->with($command);
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
         $cluster->useClusterSlots(false);
 
         $cluster->add($connection1);
@@ -640,19 +634,18 @@ class RedisClusterTest extends PredisTestCase
                 'value:5001'
             );
 
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory
             ->expects($this->once())
             ->method('create')
             ->with([
-                'scheme' => 'tcp',
                 'host' => '127.0.0.1',
                 'port' => '9381',
             ])
             ->willReturn($connection4);
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -713,7 +706,6 @@ class RedisClusterTest extends PredisTestCase
             ->expects($this->once())
             ->method('create')
             ->with([
-                'scheme' => 'tcp',
                 'host' => '127.0.0.1',
                 'port' => '9381',
             ])
@@ -723,7 +715,7 @@ class RedisClusterTest extends PredisTestCase
         /** @var RedisCluster|MockObject */
         $cluster = $this->getMockBuilder('Predis\Connection\Cluster\RedisCluster')
             ->onlyMethods(['getRandomConnection'])
-            ->setConstructorArgs([$factory])
+            ->setConstructorArgs([$factory, new Parameters()])
             ->getMock();
         $cluster
             ->expects($this->never())
@@ -749,13 +741,13 @@ class RedisClusterTest extends PredisTestCase
         $this->expectException('Predis\ClientException');
         $this->expectExceptionMessage('No connections available in the pool');
 
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory
             ->expects($this->never())
             ->method('create');
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
 
         $cluster->executeCommand(
             Command\RawCommand::create('get', 'node:1001')
@@ -767,13 +759,13 @@ class RedisClusterTest extends PredisTestCase
      */
     public function testAskSlotMapReturnEmptyArrayOnEmptyConnectionsPool(): void
     {
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory
             ->expects($this->never())
             ->method('create');
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
         $cluster->askSlotMap();
 
         $this->assertCount(0, $cluster->getSlotMap());
@@ -830,7 +822,7 @@ class RedisClusterTest extends PredisTestCase
         /** @var RedisCluster|MockObject */
         $cluster = $this->getMockBuilder('Predis\Connection\Cluster\RedisCluster')
             ->onlyMethods(['getRandomConnection'])
-            ->setConstructorArgs([$factory])
+            ->setConstructorArgs([$factory, new Parameters()])
             ->getMock();
         $cluster
             ->expects($this->exactly(3))
@@ -896,7 +888,7 @@ class RedisClusterTest extends PredisTestCase
         /** @var RedisCluster|MockObject */
         $cluster = $this->getMockBuilder('Predis\Connection\Cluster\RedisCluster')
             ->onlyMethods(['getRandomConnection'])
-            ->setConstructorArgs([$factory])
+            ->setConstructorArgs([$factory, new Parameters()])
             ->getMock();
         $cluster
             ->expects($this->exactly(2))
@@ -922,7 +914,7 @@ class RedisClusterTest extends PredisTestCase
         $connection1 = $this->getMockConnection('tcp://127.0.0.1:6379');
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -967,13 +959,13 @@ class RedisClusterTest extends PredisTestCase
                 'foobar'
             );
 
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory
             ->expects($this->never())
             ->method('create');
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
         $cluster->useClusterSlots(false);
 
         $cluster->add($connection1);
@@ -1018,19 +1010,18 @@ class RedisClusterTest extends PredisTestCase
                 'foobar'
             );
 
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory
             ->expects($this->once())
             ->method('create')
             ->with([
-                'scheme' => 'tcp',
                 'host' => '127.0.0.1',
                 'port' => '6381',
             ])
             ->willReturn($connection3);
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
         $cluster->useClusterSlots(false);
 
         $cluster->add($connection1);
@@ -1064,11 +1055,11 @@ class RedisClusterTest extends PredisTestCase
             ->with($command)
             ->willReturnOnConsecutiveCalls('foobar', 'foobar');
 
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory->expects($this->never())->method('create');
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
         $cluster->useClusterSlots(false);
 
         $cluster->add($connection1);
@@ -1107,70 +1098,18 @@ class RedisClusterTest extends PredisTestCase
             ->with($command)
             ->willReturnOnConsecutiveCalls('foobar', 'foobar');
 
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory
             ->expects($this->once())
             ->method('create')
             ->with([
-                'scheme' => 'tcp',
                 'host' => '127.0.0.1',
                 'port' => '6381',
             ])
             ->willReturn($connection3);
 
-        $cluster = new RedisCluster($factory);
-        $cluster->useClusterSlots(false);
-
-        $cluster->add($connection1);
-        $cluster->add($connection2);
-
-        $this->assertSame('foobar', $cluster->executeCommand($command));
-        $this->assertSame('foobar', $cluster->executeCommand($command));
-        $this->assertCount(3, $cluster);
-    }
-
-    /**
-     * @group disconnected
-     */
-    public function testNotTCPMovedResponseWithConnectionNotInPool(): void
-    {
-        $movedResponse = new Response\Error('MOVED 1970 127.0.0.1:6381');
-
-        $command = $this->getCommandFactory()->create('get', ['node:1001']);
-
-        $connection1 = $this->getMockConnection('tls://127.0.0.1:6379');
-        $connection1
-            ->expects($this->once())
-            ->method('executeCommand')
-            ->with($command)
-            ->willReturn($movedResponse);
-
-        $connection2 = $this->getMockConnection('tls://127.0.0.1:6380');
-        $connection2
-            ->expects($this->never())
-            ->method('executeCommand');
-
-        $connection3 = $this->getMockConnection('tls://127.0.0.1:6381');
-        $connection3
-            ->expects($this->exactly(2))
-            ->method('executeCommand')
-            ->with($command)
-            ->willReturnOnConsecutiveCalls('foobar', 'foobar');
-
-        /** @var Connection\FactoryInterface|MockObject */
-        $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
-        $factory
-            ->expects($this->once())
-            ->method('create')
-            ->with([
-                'scheme' => 'tls',
-                'host' => '127.0.0.1',
-                'port' => '6381',
-            ])
-            ->willReturn($connection3);
-
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
         $cluster->useClusterSlots(false);
 
         $cluster->add($connection1);
@@ -1204,19 +1143,18 @@ class RedisClusterTest extends PredisTestCase
             ->with($command)
             ->willReturn('foobar');
 
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory
             ->expects($this->once())
             ->method('create')
             ->with([
-                'scheme' => 'tcp',
                 'host' => '2001:db8:0:f101::2',
                 'port' => '6379',
             ])
             ->willReturn($connection2);
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
         $cluster->useClusterSlots(false);
 
         $cluster->add($connection1);
@@ -1257,10 +1195,10 @@ class RedisClusterTest extends PredisTestCase
             ))
             ->willReturn($response);
 
-        /** @var Connection\FactoryInterface */
+        /** @var FactoryInterface */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
 
         $cluster->add($connection1);
 
@@ -1302,19 +1240,18 @@ class RedisClusterTest extends PredisTestCase
                 'foobar'
             );
 
-        /** @var Connection\FactoryInterface|MockObject */
+        /** @var FactoryInterface|MockObject */
         $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
         $factory
             ->expects($this->once())
             ->method('create')
             ->with([
-                'scheme' => 'tcp',
                 'host' => '127.0.0.1',
                 'port' => '6380',
             ])
             ->willReturn($connection2);
 
-        $cluster = new RedisCluster($factory);
+        $cluster = new RedisCluster($factory, new Parameters());
 
         $cluster->add($connection1);
 
@@ -1346,7 +1283,7 @@ class RedisClusterTest extends PredisTestCase
 
         $ping = $this->getCommandFactory()->create('ping');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($this->getMockConnection('tcp://127.0.0.1:6379'));
 
@@ -1363,7 +1300,7 @@ class RedisClusterTest extends PredisTestCase
         $connection2 = $this->getMockConnection('tcp://127.0.0.1:6380?slots=5461-10922');
         $connection3 = $this->getMockConnection('tcp://127.0.0.1:6381?slots=10923-16383');
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
 
         $cluster->add($connection1);
         $cluster->add($connection2);
@@ -1396,7 +1333,7 @@ class RedisClusterTest extends PredisTestCase
                         $clusterDownError,
                         'foobar'));
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
         $cluster->useClusterSlots(false);
         $cluster->setRetryLimit(2);
         $cluster->add($connection1);
@@ -1428,7 +1365,7 @@ class RedisClusterTest extends PredisTestCase
                         $clusterDownError
                     ));
 
-        $cluster = new RedisCluster(new Connection\Factory());
+        $cluster = new RedisCluster(new Connection\Factory(), new Parameters());
         $cluster->useClusterSlots(false);
         $cluster->setRetryLimit(2);
         $cluster->add($connection1);
@@ -1489,7 +1426,7 @@ class RedisClusterTest extends PredisTestCase
         /** @var RedisCluster|MockObject */
         $cluster = $this->getMockBuilder('Predis\Connection\Cluster\RedisCluster')
             ->onlyMethods(['getRandomConnection'])
-            ->setConstructorArgs([$factory])
+            ->setConstructorArgs([$factory, new Parameters()])
             ->getMock();
         $cluster
             ->expects($this->exactly(3))
@@ -1514,4 +1451,131 @@ class RedisClusterTest extends PredisTestCase
 
         $this->assertCount(16384, $cluster->getSlotMap());
     }
+
+    /**
+     * @group disconnected
+     */
+    public function testGetParameters(): void
+    {
+        $connection = $this->getMockConnection('tcp://127.0.0.1:7001?protocol=3');
+        $factory = $this->getMockBuilder('Predis\Connection\FactoryInterface')->getMock();
+
+        $expectedParameters = new Parameters([
+            'scheme' => 'tcp',
+            'host' => '127.0.0.1',
+            'port' => 7001,
+            'protocol' => '3',
+        ]);
+
+        $cluster = new RedisCluster($factory, $expectedParameters);
+
+        $this->assertEquals($expectedParameters, $cluster->getParameters());
+    }
+
+    /**
+     * @group disconnected
+     */
+    public function testExecuteCommandOnEachNode(): void
+    {
+        $mockCommand = $this->getMockBuilder(Command\CommandInterface::class)->getMock();
+        $factory = $this->getMockBuilder(FactoryInterface::class)->getMock();
+
+        $connection1 = $this->getMockConnection('tcp://127.0.0.1:7001');
+        $connection2 = $this->getMockConnection('tcp://127.0.0.1:7002');
+        $connection3 = $this->getMockConnection('tcp://127.0.0.1:7003');
+
+        $connection1
+            ->expects($this->once())
+            ->method('executeCommand')
+            ->with($mockCommand)
+            ->willReturn('response1');
+
+        $connection2
+            ->expects($this->once())
+            ->method('executeCommand')
+            ->with($mockCommand)
+            ->willReturn('response2');
+
+        $connection3
+            ->expects($this->once())
+            ->method('executeCommand')
+            ->with($mockCommand)
+            ->willReturn('response3');
+
+        $cluster = new RedisCluster($factory, new Parameters());
+
+        $cluster->add($connection1);
+        $cluster->add($connection2);
+        $cluster->add($connection3);
+
+        $this->assertEquals(['response1', 'response2', 'response3'], $cluster->executeCommandOnEachNode($mockCommand));
+    }
+
+    /**
+     * @group disconnected
+     */
+    public function testCreatesRelayConnectionsCluster(): void
+    {
+        $factory = $this->getMockBuilder(Connection\RelayFactory::class)->getMock();
+        $expectedConnection = $this
+            ->getMockBuilder(Connection\RelayConnection::class)
+            ->disableOriginalConstructor()
+            ->getMock();
+        $parameters = new Parameters([
+            'scheme' => 'tcp',
+            'host' => '127.0.0.1',
+            'port' => 7001,
+            'protocol' => '3',
+        ]);
+
+        $cluster = new RedisCluster($factory, $parameters);
+
+        $cluster->add($expectedConnection);
+
+        $this->assertInstanceOf(Connection\RelayConnection::class, $cluster->getConnectionBySlot(9999));
+    }
+
+    /**
+     * @group disconnected
+     */
+    public function testWrite(): void
+    {
+        $command1 = new Command\Redis\GET();
+        $command1->setArguments(['arg1']);
+
+        $command2 = new Command\Redis\GET();
+        $command2->setArguments(['arg2']);
+
+        $command3 = new Command\Redis\GET();
+        $command3->setArguments(['arg3']);
+
+        $factory = $this->getMockBuilder(FactoryInterface::class)->getMock();
+
+        $connection1 = $this->getMockConnection('tcp://127.0.0.1:7001');
+        $connection2 = $this->getMockConnection('tcp://127.0.0.1:7002');
+        $connection3 = $this->getMockConnection('tcp://127.0.0.1:7003');
+
+        $connection1
+            ->expects($this->once())
+            ->method('write')
+            ->with($command3->serializeCommand());
+
+        $connection2
+            ->expects($this->once())
+            ->method('write')
+            ->with($command2->serializeCommand());
+
+        $connection3
+            ->expects($this->once())
+            ->method('write')
+            ->with($command1->serializeCommand());
+
+        $cluster = new RedisCluster($factory, new Parameters());
+
+        $cluster->add($connection1);
+        $cluster->add($connection2);
+        $cluster->add($connection3);
+
+        $cluster->write($command1->serializeCommand() . $command2->serializeCommand() . $command3->serializeCommand());
+    }
 }
