@@ -403,17 +403,6 @@ class ParametersTest extends PredisTestCase
         $this->assertSame($expected, Parameters::parse($uri));
     }
 
-    /**
-     * @group disconnected
-     */
-    public function testSetParameters(): void
-    {
-        $parameters = new Parameters();
-        $parameters->property = 'value';
-
-        $this->assertEquals('value', $parameters->property);
-    }
-
     // ******************************************************************** //
     // ---- HELPER METHODS ------------------------------------------------ //
     // ******************************************************************** //
@@ -429,6 +418,7 @@ class ParametersTest extends PredisTestCase
             'scheme' => 'tcp',
             'host' => '127.0.0.1',
             'port' => 6379,
+            'protocol' => 2,
         ];
     }
 
