@@ -51,17 +51,17 @@ class SentinelReplicationTest extends PredisTestCase
     /**
      * @group disconnected
      */
-    public function testParametersForSentinelConnectionShouldIgnoreDatabaseAndPassword(): void
+    public function testParametersForSentinelConnectionShouldIgnoreDatabase(): void
     {
         $replication = $this->getReplicationConnection('svc', [
-            'tcp://127.0.0.1:5381?role=sentinel&database=1&username=myusername',
+            'tcp://127.0.0.1:5381?role=sentinel&database=1&username=myusername&password=password',
         ]);
 
         $parameters = $replication->getSentinelConnection()->getParameters()->toArray();
 
         $this->assertArrayNotHasKey('database', $parameters, 'Parameter `database` was expected to not exist in connection parameters');
-        $this->assertArrayNotHasKey('username', $parameters, 'Parameter `username` was expected to not exist in connection parameters');
-        $this->assertArrayNotHasKey('password', $parameters, 'Parameter `password` was expected to not exist in connection parameters');
+        $this->assertArrayHasKey('username', $parameters, 'Parameter `username` was expected to not exist in connection parameters');
+        $this->assertArrayHasKey('password', $parameters, 'Parameter `password` was expected to not exist in connection parameters');
     }
 
     /**
@@ -1517,6 +1517,88 @@ class SentinelReplicationTest extends PredisTestCase
         $replication->updateSentinels();
     }
 
+    /**
+     * @dataProvider connectionsProvider
+     * @group disconnected
+     */
+    public function testGetParameters(string $connection): void
+    {
+        $sentinel = $this->getMockSentinelConnection('tcp://127.0.0.1:5381?role=sentinel');
+        $connection = $this->getMockConnection($connection);
+
+        $replication = $this->getReplicationConnection('srv', [$sentinel]);
+        $replication->add($connection);
+
+        $this->assertSame($connection->getParameters(), $replication->getParameters());
+    }
+
+    /**
+     * @group disconnected
+     * @return void
+     */
+    public function testGetParametersReturnsSentinelParametersOnEmptyConnectionPool(): void
+    {
+        $sentinel = $this->getMockSentinelConnection('tcp://127.0.0.1:5381?role=sentinel');
+
+        $replication = $this->getReplicationConnection('srv', [$sentinel]);
+
+        $this->assertSame($sentinel->getParameters(), $replication->getParameters());
+    }
+
+    /**
+     * @group disconnected
+     */
+    public function testWrite(): void
+    {
+        $command1 = new Command\Redis\Search\FTSEARCH();
+        $command1->setArguments(['arg1', '*']);
+
+        $command2 = new Command\Redis\Search\FTSEARCH();
+        $command2->setArguments(['arg2', '*']);
+
+        $command3 = new Command\Redis\Search\FTSEARCH();
+        $command3->setArguments(['arg3', '*']);
+
+        $sentinel = $this->getMockSentinelConnection('tcp://127.0.0.1:5381?role=sentinel');
+        $master = $this->getMockConnection('tcp://127.0.0.1:6379?role=master');
+        $slave = $this->getMockConnection('tcp://127.0.0.1:6380?role=slave');
+        $strategy = new Replication\ReplicationStrategy();
+        $factory = new Connection\Factory();
+
+        $master
+            ->expects($this->exactly(3))
+            ->method('isConnected')
+            ->willReturn(true);
+
+        $slave
+            ->expects($this->never())
+            ->method('write');
+
+        $master
+            ->expects($this->exactly(3))
+            ->method('write')
+            ->withConsecutive(
+                [$command1->serializeCommand()],
+                [$command2->serializeCommand()],
+                [$command3->serializeCommand()]
+            );
+
+        $replication = new SentinelReplication('svc', [$sentinel], $factory, $strategy);
+
+        $replication->add($master);
+        $replication->add($slave);
+
+        $replication->write($command1->serializeCommand() . $command2->serializeCommand() . $command3->serializeCommand());
+    }
+
+    public function connectionsProvider(): array
+    {
+        return [
+            'master connection' => ['tcp://127.0.0.1:6379?role=master'],
+            'slave connection' => ['tcp://127.0.0.1:6379'],
+        ];
+    }
+
     // ******************************************************************** //
     // ---- HELPER METHODS ------------------------------------------------ //
     // ******************************************************************** //
