@@ -13,6 +13,8 @@
 namespace Predis\Pipeline;
 
 use Predis\Client;
+use Predis\Command\Redis\PING;
+use Predis\Connection\Parameters;
 use Predis\Response;
 use PredisTestCase;
 
@@ -25,6 +27,7 @@ class AtomicTest extends PredisTestCase
     {
         $pong = new Response\Status('PONG');
         $queued = new Response\Status('QUEUED');
+        $buffer = (new PING())->serializeCommand() . (new PING())->serializeCommand() . (new PING())->serializeCommand();
 
         $connection = $this->getMockBuilder('Predis\Connection\NodeConnectionInterface')->getMock();
         $connection
@@ -39,13 +42,9 @@ class AtomicTest extends PredisTestCase
                 [$pong, $pong, $pong]
             );
         $connection
-            ->expects($this->exactly(3))
-            ->method('writeRequest')
-            ->withConsecutive(
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')]
-            );
+            ->expects($this->once())
+            ->method('write')
+            ->with($buffer);
         $connection
             ->expects($this->exactly(3))
             ->method('readResponse')
@@ -55,6 +54,11 @@ class AtomicTest extends PredisTestCase
                 $queued
             );
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $pipeline = new Atomic(new Client($connection));
 
         $pipeline->ping();
@@ -69,6 +73,7 @@ class AtomicTest extends PredisTestCase
      */
     public function testThrowsExceptionOnAbortedTransaction(): void
     {
+        $buffer = (new PING())->serializeCommand() . (new PING())->serializeCommand() . (new PING())->serializeCommand();
         $this->expectException('Predis\ClientException');
         $this->expectExceptionMessage('The underlying transaction has been aborted by the server');
 
@@ -87,13 +92,9 @@ class AtomicTest extends PredisTestCase
                 null
             );
         $connection
-            ->expects($this->exactly(3))
-            ->method('writeRequest')
-            ->withConsecutive(
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')]
-            );
+            ->expects($this->once())
+            ->method('write')
+            ->with($buffer);
         $connection
             ->expects($this->exactly(3))
             ->method('readResponse')
@@ -117,6 +118,7 @@ class AtomicTest extends PredisTestCase
      */
     public function testPipelineWithErrorInTransaction(): void
     {
+        $buffer = (new PING())->serializeCommand() . (new PING())->serializeCommand() . (new PING())->serializeCommand();
         $this->expectException('Predis\Response\ServerException');
         $this->expectExceptionMessage('ERR Test error');
 
@@ -136,13 +138,9 @@ class AtomicTest extends PredisTestCase
                 new Response\Status('OK')
             );
         $connection
-            ->expects($this->exactly(3))
-            ->method('writeRequest')
-            ->withConsecutive(
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')]
-            );
+            ->expects($this->once())
+            ->method('write')
+            ->with($buffer);
         $connection
             ->expects($this->exactly(3))
             ->method('readResponse')
@@ -166,6 +164,7 @@ class AtomicTest extends PredisTestCase
      */
     public function testThrowsServerExceptionOnResponseErrorByDefault(): void
     {
+        $buffer = (new PING())->serializeCommand() . (new PING())->serializeCommand();
         $this->expectException('Predis\Response\ServerException');
         $this->expectExceptionMessage('ERR Test error');
 
@@ -182,12 +181,9 @@ class AtomicTest extends PredisTestCase
                 new Response\Status('OK')
             );
         $connection
-            ->expects($this->exactly(2))
-            ->method('writeRequest')
-            ->withConsecutive(
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')]
-            );
+            ->expects($this->once())
+            ->method('write')
+            ->with($buffer);
         $connection
             ->expects($this->once())
             ->method('readResponse')
@@ -208,6 +204,7 @@ class AtomicTest extends PredisTestCase
      */
     public function testReturnsResponseErrorWithClientExceptionsSetToFalse(): void
     {
+        $buffer = (new PING())->serializeCommand() . (new PING())->serializeCommand() . (new PING())->serializeCommand();
         $pong = new Response\Status('PONG');
         $queued = new Response\Status('QUEUED');
         $error = new Response\Error('ERR Test error');
@@ -225,13 +222,9 @@ class AtomicTest extends PredisTestCase
                 [$pong, $pong, $error]
             );
         $connection
-            ->expects($this->exactly(3))
-            ->method('writeRequest')
-            ->withConsecutive(
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')],
-                [$this->isRedisCommand('PING')]
-            );
+            ->expects($this->once())
+            ->method('write')
+            ->with($buffer);
         $connection
             ->expects($this->exactly(3))
             ->method('readResponse')
@@ -241,6 +234,11 @@ class AtomicTest extends PredisTestCase
                 $queued
             );
 
+        $connection
+            ->expects($this->once())
+            ->method('getParameters')
+            ->willReturn(new Parameters(['protocol' => 2]));
+
         $pipeline = new Atomic(new Client($connection, ['exceptions' => false]));
 
         $pipeline->ping();
